@@ -1,6 +1,6 @@
-import filters
-from l_queries import *
-from api import run_query
+from pysmashgg import filters
+from pysmashgg.l_queries import *
+from pysmashgg.api import run_query
 
 # Shows metadata for a league
 def show(league_name, header, auto_retry):
